==> flink-1.18.1-src.tgz: flink-1.18.1/flink-table/flink-table-planner/src/test/scala/org/apache/flink/table/planner/plan/rules/logical/FlinkAggregateExpandDistinctAggregatesRuleTest.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.table.planner.plan.rules.logical

import org.apache.flink.table.planner.plan.common.DistinctAggregateTestBase
import org.apache.flink.table.planner.plan.optimize.program.FlinkBatchProgram

import org.junit.{Before, Test}

/** Test for [[FlinkAggregateExpandDistinctAggregatesRule]]. */
class FlinkAggregateExpandDistinctAggregatesRuleTest extends DistinctAggregateTestBase(false) {

  @Before
  override def setup(): Unit = {
    util.buildBatchProgram(FlinkBatchProgram.PHYSICAL)
    super.setup()
  }

  @Test
  def testSingleDistinctAggOnMultiColumns(): Unit = {
    util.verifyRelPlan("SELECT COUNT(DISTINCT a, b) FROM MyTable")
  }

  @Test
  def testSingleDistinctAggOnMultiColumnsWithGroupingSets(): Unit = {
    util.verifyRelPlan("SELECT COUNT(DISTINCT a, b) FROM MyTable2 GROUP BY GROUPING SETS (c, d)")
  }
}

==> flink-1.20.3-src.tgz: flink-1.20.3/flink-table/flink-table-planner/src/test/scala/org/apache/flink/table/planner/plan/rules/logical/FlinkAggregateExpandDistinctAggregatesRuleTest.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.table.planner.plan.rules.logical

import org.apache.flink.table.planner.plan.common.DistinctAggregateTestBase
import org.apache.flink.table.planner.plan.optimize.program.FlinkBatchProgram

import org.junit.jupiter.api.{BeforeEach, Test}

/** Test for [[FlinkAggregateExpandDistinctAggregatesRule]]. */
class FlinkAggregateExpandDistinctAggregatesRuleTest extends DistinctAggregateTestBase(false) {

  @BeforeEach
  override def setup(): Unit = {
    util.buildBatchProgram(FlinkBatchProgram.PHYSICAL)
    super.setup()
  }

  @Test
  def testSingleDistinctAggOnMultiColumns(): Unit = {
    util.verifyRelPlan("SELECT COUNT(DISTINCT a, b) FROM MyTable")
  }

  @Test
  def testSingleDistinctAggOnMultiColumnsWithGroupingSets(): Unit = {
    util.verifyRelPlan("SELECT COUNT(DISTINCT a, b) FROM MyTable2 GROUP BY GROUPING SETS (c, d)")
  }
}
